pub struct DownloadFileRes {
pub chunk: Option<FileChunk>,
pub chunk_signature: Option<Ed25519Signature>,
pub muid: Option<MessageUniqueId>,
}Fields
chunk: Option<FileChunk>Here is MUID which is has original date and nonce from sender to match the signature
chunk_signature: Option<Ed25519Signature>muid: Option<MessageUniqueId>Here is another MUID but it has actual date and new nonce. It belongs to server verification