pub struct GetJoinRequestStatusRes {
pub status: i32,
pub ecies_encrypted_room_key: Option<String>,
pub muid: Option<MessageUniqueId>,
}Fields
status: i32ecies_encrypted_room_key: Option<String>muid: Option<MessageUniqueId>Implementations
Sourceimpl GetJoinRequestStatusRes
impl GetJoinRequestStatusRes
Sourcepub fn status(&self) -> JoinRequestStatus
pub fn status(&self) -> JoinRequestStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: JoinRequestStatus)
pub fn set_status(&mut self, value: JoinRequestStatus)
Sets status to the provided enum value.
Sourcepub fn ecies_encrypted_room_key(&self) -> &str
pub fn ecies_encrypted_room_key(&self) -> &str
Returns the value of ecies_encrypted_room_key, or the default value if ecies_encrypted_room_key is unset.