pub struct GetMessageRes {
pub message: Option<Message>,
pub signature: Option<Ed25519Signature>,
pub muid: Option<MessageUniqueId>,
}Fields
message: Option<Message>Here is MUID which is has original date and nonce from sender to match the signature
signature: Option<Ed25519Signature>64 bytes ed25519 signature of encoded Message protobuf-object
muid: Option<MessageUniqueId>Here is another MUID but it has actual date and new nonce. It belongs to server verification